# hmta - How Much Time Anime

Do you wanna know how much time would take you to watch an anime? Well, this is your tool.

### Installation

- Arch
```bash
yay -S hmta
```
- Fedora
> Coming soon...

### Usage
```bash
hmta
```

It will prompt you for the anime name, and then you would have to select the correct anime or season. 
After that, it will give you an estimate of how much time it would take you to watch that anime.
